# Auto PWLF
Piecewise Linear Fit with option to automatically find the optimal number of line segments.

[Documentation](https://autopwlf.readthedocs.io/en/latest/#)

The piecewise fitting uses the [pwlf module](https://github.com/cjekel/piecewise_linear_fit_py) with full credit to all contributors to this package.
AutoPWLF exists as an add-on to this package.


![image](https://github.com/user-attachments/assets/cb21b3c2-2ccc-49ff-ab42-f4aa2b991091)

